@@ -16,6 +16,7 @@ from typing import (
     Union,
 )
 
+import attrs
 import pytest
 from attrs import Factory, define, field, fields, has, make_class
 from hypothesis import assume, given
@@ -32,6 +33,7 @@ from cattrs.fns import raise_error
 from cattrs.gen import make_dict_structure_fn, override
 
 from ._compat import is_py310_plus
+from .helpers import assert_only_unstructured
 from .typed import (
     nested_typed_classes,
     simple_typed_attrs,
@@ -54,7 +56,7 @@ def test_simple_roundtrip(cls_and_vals, detailed_validation):
     cl, vals, kwargs = cls_and_vals
     inst = cl(*vals, **kwargs)
     unstructured = converter.unstructure(inst)
-    assert "Hyp" not in repr(unstructured)
+    assert_only_unstructured(unstructured)
     assert inst == converter.structure(unstructured, cl)
 
 
@@ -73,7 +75,7 @@ def test_simple_roundtrip_tuple(cls_and_vals, dv: bool):
     cl, vals, _ = cls_and_vals
     inst = cl(*vals)
     unstructured = converter.unstructure(inst)
-    assert "Hyp" not in repr(unstructured)
+    assert_only_unstructured(unstructured)
     assert inst == converter.structure(unstructured, cl)
 
 
@@ -125,7 +127,7 @@ def test_simple_roundtrip_with_extra_keys_forbidden(cls_and_vals, strat):
     assume(strat is UnstructureStrategy.AS_DICT or not kwargs)
     inst = cl(*vals, **kwargs)
     unstructured = converter.unstructure(inst)
-    assert "Hyp" not in repr(unstructured)
+    assert_only_unstructured(unstructured)
     assert inst == converter.structure(unstructured, cl)
 
 
@@ -338,6 +340,64 @@ def test_omit_default_roundtrip(cl_and_vals):
     assert inst == converter.structure(unstructured, C)
 
 
+@given(simple_typed_classes(defaults="always", allow_nan=False))
+def test_omit_default_with_attrs_converter_roundtrip(cl_and_vals):
+    """
+    Omit default with an attrs converter works.
+    """
+    converter = Converter(omit_if_default=True)
+    cl, vals, kwargs = cl_and_vals
+
+    @define
+    class C:
+        a1: int = field(default="1", converter=int)
+        a2: int = field(default="1", converter=attrs.Converter(int))
+        a3: int = field(factory=lambda: "1", converter=int)
+        a4: int = field(factory=lambda: "1", converter=attrs.Converter(int))
+        a5: int = field(
+            factory=lambda: "2",
+            converter=attrs.Converter(
+                lambda obj, self: int(obj) + self.a4, takes_self=True
+            ),
+        )
+        a6: int = field(
+            factory=lambda: "2",
+            converter=attrs.Converter(
+                lambda obj, field: int(obj) + int(field.default.factory()) - 2,
+                takes_field=True,
+            ),
+        )
+        a7: int = field(
+            factory=lambda: "3",
+            converter=attrs.Converter(
+                lambda obj, self, field: (
+                    int(obj) + self.a6 + int(field.default.factory()) - 3
+                ),
+                takes_self=True,
+                takes_field=True,
+            ),
+        )
+        c: cl = Factory(lambda: cl(*vals, **kwargs))
+
+    inst = C()
+    unstructured = converter.unstructure(inst)
+    assert unstructured == {}
+    assert inst == converter.structure(unstructured, C)
+
+    inst = C(0, 0, 0, 0, 0, 0, 0)
+    unstructured = converter.unstructure(inst)
+    assert unstructured == {
+        "a1": 0,
+        "a2": 0,
+        "a3": 0,
+        "a4": 0,
+        "a5": 0,
+        "a6": 0,
+        "a7": 0,
+    }
+    assert inst == converter.structure(unstructured, C)
+
+
 def test_dict_roundtrip_with_alias():
     """
     A class with an aliased attribute can be unstructured and structured.
