@@ -13,6 +13,7 @@ from cattrs._compat import adapted_fields, fields
 from cattrs.errors import ClassValidationError, ForbiddenExtraKeysError
 from cattrs.gen import make_dict_structure_fn, make_dict_unstructure_fn, override
 
+from .helpers import assert_only_unstructured
 from .typed import nested_typed_classes, simple_typed_classes, simple_typed_dataclasses
 from .untyped import nested_classes, simple_classes
 
@@ -143,8 +144,7 @@ def test_individual_overrides(converter_cls, cl_and_vals):
     inst = cl(*vals, **kwargs)
 
     res = converter.unstructure(inst)
-    assert "Hyp" not in repr(res)
-    assert "Factory" not in repr(res)
+    assert_only_unstructured(res)
 
     for attr, val in zip(fields, vals):
         if attr.name == chosen_name:
@@ -181,7 +181,7 @@ def test_unmodified_generated_structuring(cl_and_vals, dv: bool):
 
     unstructured = converter.unstructure(inst)
 
-    assert "Hyp" not in repr(unstructured)
+    assert_only_unstructured(unstructured)
 
     converter.register_structure_hook(cl, fn)
 
@@ -327,7 +327,7 @@ def test_type_names_with_quotes():
     assert converter.structure({1: 1}, Dict[Annotated[int, "'"], int]) == {1: 1}
 
     converter.register_structure_hook_func(
-        lambda t: t is Union[Literal["a", 2, 3], Literal[4]], lambda v, _: v
+        lambda t: t == Union[Literal["a", 2, 3], Literal[4]], lambda v, _: v
     )
     assert converter.structure(
         {2: "a"}, Dict[Union[Literal["a", 2, 3], Literal[4]], str]
@@ -419,6 +419,30 @@ def test_alias_keys(converter: BaseConverter) -> None:
     )
 
 
+def test_alias_implicit_rename(converter: BaseConverter) -> None:
+    """Attributes with aliases generate rename metadata."""
+
+    @define
+    class A:
+        a: int = field(alias="b")
+        c: int = field(alias="d", default=1)
+
+    u_fn = make_dict_unstructure_fn(A, converter, _cattrs_use_alias=True)
+    s_fn = make_dict_structure_fn(A, converter, _cattrs_use_alias=True)
+
+    assert u_fn.overrides["a"].rename == "b"
+    assert s_fn.overrides["a"].rename == "b"
+    assert u_fn.overrides["c"].rename == "d"
+    assert s_fn.overrides["c"].rename == "d"
+
+    converter.register_unstructure_hook(A, u_fn)
+    converter.register_structure_hook(A, s_fn)
+
+    assert converter.unstructure(A(1)) == {"b": 1, "d": 1}
+    assert converter.structure({"b": 1}, A) == A(1)
+    assert converter.structure({"b": 1, "d": 2}, A) == A(1, 2)
+
+
 def test_init_false(converter: BaseConverter) -> None:
     """By default init=False keys are ignored."""
 
